@@ -16,7 +16,7 @@
 #if GCC_VERSION_AT_LEAST(2,95)
 #define CK_ATTRIBUTE_UNUSED __attribute__ ((unused))
 #else
-#define CK_ATTRIBUTE_UNUSED              
+#define CK_ATTRIBUTE_UNUSED
 #endif /* GCC 2.95 */
 
 #if GCC_VERSION_AT_LEAST(2,5)
@@ -25,6 +25,21 @@
 #define CK_ATTRIBUTE_NORETURN
 #endif /* GCC 2.5 */
 
+/*
+ * Used for MSVC to create the export attribute
+ * CK_DLL_EXP is defined during the compilation of the library
+ * on the command line.
+ */
+#ifndef CK_DLL_EXP
+#define CK_DLL_EXP
+#endif
+
+#if _MSC_VER
+#include <WinSock2.h>           /* struct timeval, API used in gettimeofday implementation */
+#include <io.h>                 /* read, write */
+#include <process.h>            /* getpid */
+#endif /* _MSC_VER */
+
 /* defines size_t */
 #include <sys/types.h>
 
@@ -38,7 +53,9 @@
 #include <stdlib.h>
 
 /* provides localtime and struct tm */
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif /* !HAVE_SYS_TIME_H */
 #include <time.h>
 
 /* declares fork(), _POSIX_VERSION.  according to Autoconf.info,
@@ -64,63 +81,41 @@
 
 /* replacement functions for broken originals */
 #if !HAVE_DECL_ALARM
-unsigned int alarm (unsigned int seconds);
+CK_DLL_EXP unsigned int alarm(unsigned int seconds);
 #endif /* !HAVE_DECL_ALARM */
 
 #if !HAVE_MALLOC
-void *rpl_malloc (size_t n);
+CK_DLL_EXP void *rpl_malloc(size_t n);
 #endif /* !HAVE_MALLOC */
 
 #if !HAVE_REALLOC
-void *rpl_realloc (void *p, size_t n);
+CK_DLL_EXP void *rpl_realloc(void *p, size_t n);
 #endif /* !HAVE_REALLOC */
 
-/* functions that may be undeclared */
-#if !HAVE_DECL_FILENO
-int fileno (FILE *stream);
-#endif /* !HAVE_DECL_FILENO */
+#if !HAVE_GETPID && HAVE__GETPID
+#define getpid _getpid
+#endif /* !HAVE_GETPID && HAVE__GETPID */
+
+#if !HAVE_GETTIMEOFDAY
+CK_DLL_EXP int gettimeofday(struct timeval *tv, void *tz);
+#endif /* !HAVE_GETTIMEOFDAY */
 
 #if !HAVE_DECL_LOCALTIME_R
 #if !defined(localtime_r)
-struct tm *localtime_r (const time_t *clock, struct tm *result);
+CK_DLL_EXP struct tm *localtime_r(const time_t * clock, struct tm *result);
 #endif
 #endif /* !HAVE_DECL_LOCALTIME_R */
 
-#if !HAVE_DECL_PIPE
-int pipe (int *fildes);
-#endif /* !HAVE_DECL_PIPE */
-
-#if !HAVE_DECL_PUTENV
-int putenv (const char *string);
-#endif /* !HAVE_DECL_PUTENV */
-
-#if !HAVE_DECL_SETENV
-int setenv (const char *name, const char *value, int overwrite);
-#endif /* !HAVE_DECL_SETENV */
-
-/* our setenv implementation is currently broken */
-#if !HAVE_SETENV
-#define HAVE_WORKING_SETENV 0
-#else
-#define HAVE_WORKING_SETENV 1
-#endif
-
-#if !HAVE_DECL_SLEEP
-unsigned int sleep (unsigned int seconds);
-#endif /* !HAVE_DECL_SLEEP */
-
-#if !HAVE_DECL_STRDUP
-char *strdup (const char *str);
-#endif /* !HAVE_DECL_STRDUP */
+#if !HAVE_DECL_STRDUP && !HAVE__STRDUP
+CK_DLL_EXP char *strdup(const char *str);
+#elif !HAVE_DECL_STRDUP && HAVE__STRDUP
+#define strdup _strdup
+#endif /* !HAVE_DECL_STRDUP && HAVE__STRDUP */
 
 #if !HAVE_DECL_STRSIGNAL
-const char *strsignal (int sig);
+CK_DLL_EXP const char *strsignal(int sig);
 #endif /* !HAVE_DECL_STRSIGNAL */
 
-#if !HAVE_DECL_UNSETENV
-int unsetenv (const char *name);
-#endif /* !HAVE_DECL_UNSETENV */
-
 /* 
  * On systems where clock_gettime() is not available, or
  * on systems where some clocks may not be supported, the
@@ -149,9 +144,10 @@ int unsetenv (const char *name);
  * specified in seconds and nanoseconds. If it is not defined in
  * time.g, then we need to define it here
  */
-struct timespec {
-   time_t   tv_sec;
-   long     tv_nsec;
+struct timespec
+{
+    time_t tv_sec;
+    long tv_nsec;
 };
 #endif /* STRUCT_TIMESPEC_DEFINITION_MISSING */
 
@@ -167,18 +163,6 @@ struct itimerspec
 };
 #endif /* STRUCT_ITIMERSPEC_DEFINITION_MISSING */
 
-/* 
- * As the functions which use timer_t are not defined on the system, 
- * the timer_t type probably also is not defined.
- */
-typedef int timer_t;
-
-/*
- * As the functions which use clockid_t are not defined on the system,
- * the clockid_t type probably also is not defined.
- */
-typedef int clockid_t;
-
 /* 
  * Do a simple forward declaration in case the struct is not defined.
  * In the versions of timer_create in libcompat, sigevent is never
@@ -186,10 +170,13 @@ typedef int clockid_t;
  */
 struct sigevent;
 
-int clock_gettime(clockid_t clk_id, struct timespec *ts);
-int timer_create(int clockid, struct sigevent *sevp, timer_t *timerid);
-int timer_settime(timer_t timerid, int flags, const struct itimerspec *new_value, struct itimerspec * old_value);
-int timer_delete(timer_t timerid);
+CK_DLL_EXP int clock_gettime(clockid_t clk_id, struct timespec *ts);
+CK_DLL_EXP int timer_create(clockid_t clockid, struct sigevent *sevp,
+                            timer_t * timerid);
+CK_DLL_EXP int timer_settime(timer_t timerid, int flags,
+                             const struct itimerspec *new_value,
+                             struct itimerspec *old_value);
+CK_DLL_EXP int timer_delete(timer_t timerid);
 #endif /* HAVE_LIBRT */
 
 /*
@@ -202,21 +189,20 @@ int timer_delete(timer_t timerid);
 #endif
 #if HAVE_STDARG_H
 #include <stdarg.h>
+
 #if !HAVE_VSNPRINTF
-int rpl_vsnprintf(char *, size_t, const char *, va_list);
+CK_DLL_EXP int rpl_vsnprintf(char *, size_t, const char *, va_list);
+
+#define vsnprintf rpl_vsnprintf
 #endif
 #if !HAVE_SNPRINTF
-int rpl_snprintf(char *, size_t, const char *, ...);
-#endif
-#if !HAVE_VASPRINTF
-int rpl_vasprintf(char **, const char *, va_list);
-#endif
-#if !HAVE_ASPRINTF
-int rpl_asprintf(char **, const char *, ...);
+CK_DLL_EXP int rpl_snprintf(char *, size_t, const char *, ...);
+
+#define snprintf rpl_snprintf
 #endif
 #endif /* HAVE_STDARG_H */
 
 /* silence warnings about an empty library */
-void ck_do_nothing (void) CK_ATTRIBUTE_NORETURN;
+CK_DLL_EXP void ck_do_nothing(void) CK_ATTRIBUTE_NORETURN;
 
 #endif /* !LIBCOMPAT_H */
