@@ -27,7 +27,7 @@ static char signal_8_str[SIG_STR_LEN];
 /* FIXME: all these line numbers are kind of hard to maintain */
 static master_test_t master_tests[] = {
   { "Simple Tests", CK_FAILURE, "Failure expected" },
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   { "Simple Tests", CK_ERROR,   "Early exit with return value 1" },
 #endif
   { "Simple Tests", CK_PASS,    "Passed" },
@@ -35,31 +35,49 @@ static master_test_t master_tests[] = {
   { "Simple Tests", CK_PASS,    "Passed" },
   { "Simple Tests", CK_FAILURE, "This test should fail" },
   { "Simple Tests", CK_FAILURE, "Assertion '2 == 3' failed" },
+#if defined(__GNUC__)
   { "Simple Tests", CK_FAILURE, "Assertion '4 == 5' failed" },
-  { "Simple Tests", CK_FAILURE, "Failure '2 != 3' occured" },
-  { "Simple Tests", CK_FAILURE, "Failure '4 != 5' occured" },
+#endif /* __GNUC__ */
+  { "Simple Tests", CK_FAILURE, "Failure '2 != 3' occurred" },
+#if defined(__GNUC__)
+  { "Simple Tests", CK_FAILURE, "Failure '4 != 5' occurred" },
+#endif /* __GNUC__ */
   { "Simple Tests", CK_FAILURE, "3 != 4" },
   { "Simple Tests", CK_FAILURE, "5 != 6" },
   { "Simple Tests", CK_FAILURE, "7 == 7" },
+#if defined(__GNUC__)
   { "Simple Tests", CK_FAILURE, "Failed" },
+#endif /* __GNUC__ */
   { "Simple Tests", CK_FAILURE, "Failed" },
   { "Simple Tests", CK_FAILURE, "Failure expected" },
   { "Simple Tests", CK_FAILURE, "Failed" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x == y' failed" },
   { "Simple Tests", CK_FAILURE, "Assertion '0' failed" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x==y' failed: x==3, y==4" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d==2%f' failed: 3%d==1, 2%f==0" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x!=y' failed: x==3, y==3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d!=3%f' failed: 3%d==1, 3%f==1" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x<x' failed: x==2, x==2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d<3%f' failed: 3%d==1, 3%f==0" },
   { "Simple Tests", CK_FAILURE, "Assertion 'y<=x' failed: y==3, x==2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d<=2%f' failed: 3%d==1, 2%f==0" },
   { "Simple Tests", CK_FAILURE, "Assertion 'y>y' failed: y==3, y==3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d>3%f' failed: 3%d==0, 3%f==1" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x>=y' failed: x==2, y==3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d>=4%f' failed: 3%d==0, 4%f==1" },
   { "Simple Tests", CK_PASS,    "Passed" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x==y' failed: x==3, y==4" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d==1%f' failed: 3%d==1, 1%f==0" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x!=y' failed: x==3, y==3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '1%d!=1%f' failed: 1%d==0, 1%f==0" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x<x' failed: x==2, x==2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d<1%f' failed: 3%d==1, 1%f==0" },
   { "Simple Tests", CK_FAILURE, "Assertion 'y<=x' failed: y==3, x==2" },
+  { "Simple Tests", CK_FAILURE, "Assertion '3%d<=1%f' failed: 3%d==1, 1%f==0" },
   { "Simple Tests", CK_FAILURE, "Assertion 'y>y' failed: y==3, y==3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '1%d>3%f' failed: 1%d==0, 3%f==1" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x>=y' failed: x==2, y==3" },
+  { "Simple Tests", CK_FAILURE, "Assertion '1%d>=3%f' failed: 1%d==0, 3%f==1" },
   { "Simple Tests", CK_PASS,    "Passed" },
   { "Simple Tests", CK_FAILURE, "Assertion '\"test1\"==s' failed: \"test1\"==\"test1\", s==\"test2\"" },
   { "Simple Tests", CK_FAILURE, "Assertion 't!=s' failed: t==\"test2\", s==\"test2\"" },
@@ -71,7 +89,7 @@ static master_test_t master_tests[] = {
   { "Simple Tests", CK_FAILURE, "Assertion 'x==y' failed: x==0x1, y==0x2" },
   { "Simple Tests", CK_FAILURE, "Assertion 'x!=z' failed: x==0x1, z==0x1" },
   
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   { "Signal Tests", CK_ERROR,   signal_11_str },
   { "Signal Tests", CK_PASS,    "Passed" },
   { "Signal Tests", CK_ERROR,   signal_11_8_str },
@@ -81,8 +99,8 @@ static master_test_t master_tests[] = {
   { "Signal Tests", CK_ERROR,   signal_8_str },
 #endif
 
-#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK)
-#if HAVE_WORKING_SETENV
+#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) && HAVE_FORK==1
+#if HAVE_DECL_SETENV
   { "Environment Integer Timeout Tests", CK_ERROR,  "Test timeout expired" },
   { "Environment Integer Timeout Tests", CK_PASS,   "Passed" },
   { "Environment Integer Timeout Tests", CK_PASS,   "Passed" },
@@ -96,7 +114,7 @@ static master_test_t master_tests[] = {
   { "Environment Double Timeout Tests", CK_ERROR,  "Test timeout expired" },
   { "Environment Double Timeout Tests", CK_ERROR,  "Test timeout expired" },
   { "Environment Double Timeout Tests", CK_ERROR,  "Test timeout expired" },
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 
   { "Default Timeout Tests", CK_ERROR,  "Test timeout expired" },
 #ifdef HAVE_LIBRT
@@ -131,7 +149,7 @@ static master_test_t master_tests[] = {
   { "Default Timeout Tests", CK_ERROR,  "Test timeout expired" },
   { "Default Timeout Tests", CK_ERROR,  "Test timeout expired" },
   
-#if HAVE_WORKING_SETENV
+#if HAVE_DECL_SETENV
   { "Environment Integer Timeout Scaling Tests", CK_ERROR,  "Test timeout expired" },
 #ifdef HAVE_LIBRT
   { "Environment Integer Timeout Scaling Tests", CK_PASS,   "Passed" },
@@ -189,23 +207,32 @@ static master_test_t master_tests[] = {
   { "User Double Timeout Scaling Tests", CK_ERROR,  "Test timeout expired" },
   { "User Double Timeout Scaling Tests", CK_ERROR,  "Test timeout expired" },
   { "User Double Timeout Scaling Tests", CK_ERROR,  "Test timeout expired" },
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 #endif /* TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) */
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   { "Limit Tests", CK_ERROR,   "Early exit with return value 1" },
 #endif /* HAVE_FORK */
+#if MEMORY_LEAKING_TESTS_ENABLED
   { "Limit Tests", CK_FAILURE, "Completed properly" },
+#endif /* MEMORY_LEAKING_TESTS_ENABLED */
   { "Limit Tests", CK_FAILURE, "Completed properly" },
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   { "Msg and fork Tests", CK_PASS,       "Passed" },
   { "Msg and fork Tests", CK_FAILURE,    "Expected fail" },
   { "Msg and fork Tests", CK_PASS,       "Passed" },
   { "Msg and fork Tests", CK_FAILURE,    "Expected fail" },
   { "Msg and fork Tests", CK_PASS,       "Passed" },
   { "Msg and fork Tests", CK_FAILURE,    "Expected fail" },
+#endif  /* HAVE_FORK */
+
+#if defined(HAVE_FORK) && HAVE_FORK==1
+#if MEMORY_LEAKING_TESTS_ENABLED
+  { "Check Errors Tests", CK_FAILURE,    "Early exit with return value 2" },
 #endif
+  { "Check Ignore Exit Handlers", CK_FAILURE, "Failed" },
+#endif /* HAVE_FORK */
 
   { "Core", CK_PASS,    "Passed" },
   { "Core", CK_FAILURE, "We failed" }
@@ -419,7 +446,7 @@ Suite *make_master_suite (void)
      preservation of fixture values across tests, regardless
      of the order in which tests are added to the test case */
   tcase_add_test (tc_fixture, test_setup);
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   /* The remaining test runs only work if fork() is available. */
   tcase_add_test (tc_fixture, test_setup);
   tcase_add_test (tc_fixture, test_setup);
