@@ -16,7 +16,7 @@ START_TEST(test_lno)
 }
 END_TEST
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
 START_TEST(test_mark_lno)
 {
   mark_point();
@@ -167,6 +167,15 @@ START_TEST(test_ck_assert_int_eq)
 }
 END_TEST
 
+START_TEST(test_ck_assert_int_eq_with_mod)
+{
+  int d = 2;
+  int f = 1;
+  ck_assert_int_eq(3%d, 2%f);
+  #define LINENO_ck_assert_int_eq_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_int_ne)
 {
   int x = 3;
@@ -178,6 +187,15 @@ START_TEST(test_ck_assert_int_ne)
 }
 END_TEST
 
+START_TEST(test_ck_assert_int_ne_with_mod)
+{
+  int d = 2;
+  int f = 2;
+  ck_assert_int_ne(3%d, 3%f);
+  #define LINENO_ck_assert_int_ne_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_int_lt)
 {
   int x = 2;
@@ -188,6 +206,15 @@ START_TEST(test_ck_assert_int_lt)
 }
 END_TEST
 
+START_TEST(test_ck_assert_int_lt_with_mod)
+{
+  int d = 2;
+  int f = 1;
+  ck_assert_int_lt(3%d, 3%f);
+  #define LINENO_ck_assert_int_lt_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_int_le)
 {
   int x = 2;
@@ -199,6 +226,15 @@ START_TEST(test_ck_assert_int_le)
 }
 END_TEST
 
+START_TEST(test_ck_assert_int_le_with_mod)
+{
+  int d = 2;
+  int f = 1;
+  ck_assert_int_le(3%d, 2%f);
+  #define LINENO_ck_assert_int_le_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_int_gt)
 {
   int x = 2;
@@ -209,6 +245,15 @@ START_TEST(test_ck_assert_int_gt)
 }
 END_TEST
 
+START_TEST(test_ck_assert_int_gt_with_mod)
+{
+  int d = 1;
+  int f = 2;
+  ck_assert_int_gt(3%d, 3%f);
+  #define LINENO_ck_assert_int_gt_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_int_ge)
 {
   int x = 2;
@@ -220,6 +265,15 @@ START_TEST(test_ck_assert_int_ge)
 }
 END_TEST
 
+START_TEST(test_ck_assert_int_ge_with_mod)
+{
+  int d = 1;
+  int f = 3;
+  ck_assert_int_ge(3%d, 4%f);
+  #define LINENO_ck_assert_int_ge_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_int_expr)
 {
   int x = 1;
@@ -240,6 +294,15 @@ START_TEST(test_ck_assert_uint_eq)
 }
 END_TEST
 
+START_TEST(test_ck_assert_uint_eq_with_mod)
+{
+  int d = 2;
+  int f = 1;
+  ck_assert_uint_eq(3%d, 1%f);
+  #define LINENO_ck_assert_uint_eq_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_uint_ne)
 {
   unsigned int x = 3;
@@ -251,6 +314,15 @@ START_TEST(test_ck_assert_uint_ne)
 }
 END_TEST
 
+START_TEST(test_ck_assert_uint_ne_with_mod)
+{
+  int d = 1;
+  int f = 1;
+  ck_assert_uint_ne(1%d, 1%f);
+  #define LINENO_ck_assert_uint_ne_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_uint_lt)
 {
   unsigned int x = 2;
@@ -261,6 +333,15 @@ START_TEST(test_ck_assert_uint_lt)
 }
 END_TEST
 
+START_TEST(test_ck_assert_uint_lt_with_mod)
+{
+  int d = 2;
+  int f = 1;
+  ck_assert_uint_lt(3%d, 1%f);
+  #define LINENO_ck_assert_uint_lt_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_uint_le)
 {
   unsigned int x = 2;
@@ -272,6 +353,15 @@ START_TEST(test_ck_assert_uint_le)
 }
 END_TEST
 
+START_TEST(test_ck_assert_uint_le_with_mod)
+{
+  int d = 2;
+  int f = 1;
+  ck_assert_uint_le(3%d, 1%f);
+  #define LINENO_ck_assert_uint_le_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_uint_gt)
 {
   unsigned int x = 2;
@@ -282,6 +372,15 @@ START_TEST(test_ck_assert_uint_gt)
 }
 END_TEST
 
+START_TEST(test_ck_assert_uint_gt_with_mod)
+{
+  int d = 1;
+  int f = 2;
+  ck_assert_uint_gt(1%d, 3%f);
+  #define LINENO_ck_assert_uint_gt_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_uint_ge)
 {
   unsigned int x = 2;
@@ -293,6 +392,15 @@ START_TEST(test_ck_assert_uint_ge)
 }
 END_TEST
 
+START_TEST(test_ck_assert_uint_ge_with_mod)
+{
+  int d = 1;
+  int f = 2;
+  ck_assert_uint_ge(1%d, 3%f);
+  #define LINENO_ck_assert_uint_ge_with_mod _STR(__LINE__)
+}
+END_TEST
+
 START_TEST(test_ck_assert_uint_expr)
 {
   unsigned int x = 1;
@@ -399,7 +507,7 @@ START_TEST(test_ck_assert_ptr_ne)
 }
 END_TEST
 
-#if defined(HAVE_FORK)
+#if defined(HAVE_FORK) && HAVE_FORK == 1
 START_TEST(test_segv)
   #define LINENO_segv _STR(__LINE__)
 {
@@ -429,12 +537,12 @@ START_TEST(test_mark_point)
 END_TEST
 #endif
 
-#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK)
+#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) && HAVE_FORK == 1
 START_TEST(test_eternal)
   #define LINENO_eternal _STR(__LINE__)
 {
   for (;;)
-    ;
+    sleep(1);
 }
 END_TEST
 
@@ -487,7 +595,7 @@ START_TEST(test_sleep14)
 END_TEST
 #endif /* TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) */
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
 START_TEST(test_early_exit)
 {
   exit(EXIT_FAILURE);
@@ -495,6 +603,13 @@ START_TEST(test_early_exit)
 END_TEST
 #endif /* HAVE_FORK */
 
+/*
+ * The following test will leak memory because it is calling
+ * APIs inproperly. The leaked memory cannot be free'd, as
+ * the methods to do so are static. (No user of Check should
+ * call them directly).
+ */
+#if MEMORY_LEAKING_TESTS_ENABLED
 START_TEST(test_null)
 {  
   Suite *s;
@@ -510,17 +625,19 @@ START_TEST(test_null)
   ck_abort_msg("Completed properly");
 }
 END_TEST
+#endif /* MEMORY_LEAKING_TESTS_ENABLED */
 
 START_TEST(test_null_2)
 {
   SRunner *sr = srunner_create(NULL);
   srunner_run_all (sr, CK_NORMAL);
   srunner_free (sr);
+  ck_assert_int_eq(suite_tcase(NULL, NULL), 0);
   ck_abort_msg("Completed properly");
 }
 END_TEST
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
 START_TEST(test_fork1p_pass)
 {
   pid_t pid;
@@ -626,6 +743,25 @@ START_TEST(test_fork2_fail)
 END_TEST
 #endif /* HAVE_FORK */
 
+#if defined(HAVE_FORK) && HAVE_FORK == 1
+#if MEMORY_LEAKING_TESTS_ENABLED
+START_TEST(test_invalid_set_fork_status)
+  #define LINENO_invalid_set_fork_status _STR(__LINE__)
+{
+   Suite *s1;
+   TCase *tc1;
+   SRunner *sr;
+   s1 = suite_create ("suite1");
+   tc1 = tcase_create ("tcase1");
+   tcase_add_test (tc1, test_pass);
+   sr = srunner_create(s1);
+   srunner_set_fork_status (sr, -1);
+   srunner_run_all(sr, CK_SILENT);
+}
+END_TEST
+#endif /* MEMORY_LEAKING_TESTS_ENABLED */
+#endif /* HAVE_FORK */
+
 START_TEST(test_srunner)
 {
   Suite *s;
@@ -668,11 +804,35 @@ Suite *make_sub2_suite(void)
   return s;
 }
 
+#if defined(HAVE_FORK) && HAVE_FORK == 1
+void exit_handler();
+void exit_handler ()
+{
+  // This exit handler should never be executed
+  while(1)
+  {
+    sleep(1);
+  }
+}
+
+START_TEST(test_ignore_exit_handlers)
+{
+  int result = atexit(exit_handler);
+  if(result != 0)
+  {
+    ck_abort_msg("Failed to set an exit handler, test cannot proceed");
+  }
+  ck_abort();
+#define LINENO_ck_ignore_exit_handlers _STR(__LINE__)
+}
+END_TEST
+#endif /* HAVE_FORK */
+
 void init_master_tests_lineno(int num_master_tests) {
   const char * lineno[] = {
 /* Simple Tests */
     LINENO_lno,
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
     LINENO_mark_lno,
 #endif
     "-1",
@@ -680,31 +840,49 @@ void init_master_tests_lineno(int num_master_tests) {
     "-1",
     "-1",
     "-1",
+#if defined(__GNUC__)
+    "-1",
+#endif /* __GNUC__ */
+    "-1",
+#if defined(__GNUC__)
+    "-1",
+#endif /* __GNUC__ */
     "-1",
     "-1",
     "-1",
+#if defined(__GNUC__)
     "-1",
-    "-1",
-    "-1",
-    "-1",
+#endif /* __GNUC__ */
     LINENO_ck_abort,
     LINENO_ck_abort_msg,
     LINENO_ck_abort_msg_null,
     LINENO_ck_assert,
     LINENO_ck_assert_null,
     LINENO_ck_assert_int_eq,
-    LINENO_ck_assert_int_eq,
+    LINENO_ck_assert_int_eq_with_mod,
     LINENO_ck_assert_int_ne,
+    LINENO_ck_assert_int_ne_with_mod,
     LINENO_ck_assert_int_lt,
+    LINENO_ck_assert_int_lt_with_mod,
     LINENO_ck_assert_int_le,
+    LINENO_ck_assert_int_le_with_mod,
     LINENO_ck_assert_int_gt,
+    LINENO_ck_assert_int_gt_with_mod,
     LINENO_ck_assert_int_ge,
+    LINENO_ck_assert_int_ge_with_mod,
     LINENO_ck_assert_int_expr,
+    LINENO_ck_assert_int_eq,
+    LINENO_ck_assert_int_eq_with_mod,
     LINENO_ck_assert_uint_ne,
+    LINENO_ck_assert_uint_ne_with_mod,
     LINENO_ck_assert_uint_lt,
+    LINENO_ck_assert_uint_lt_with_mod,
     LINENO_ck_assert_uint_le,
+    LINENO_ck_assert_uint_le_with_mod,
     LINENO_ck_assert_uint_gt,
+    LINENO_ck_assert_uint_gt_with_mod,
     LINENO_ck_assert_uint_ge,
+    LINENO_ck_assert_uint_ge_with_mod,
     LINENO_ck_assert_uint_expr,
     LINENO_ck_assert_str_eq,
     LINENO_ck_assert_str_ne,
@@ -716,7 +894,7 @@ void init_master_tests_lineno(int num_master_tests) {
     LINENO_ck_assert_ptr_eq,
     LINENO_ck_assert_ptr_ne,
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
 /* Signal Tests */
     "-1",
     "-1",
@@ -727,8 +905,8 @@ void init_master_tests_lineno(int num_master_tests) {
     "-1",
 #endif /* HAVE_FORK */
 
-#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK)
-#if HAVE_WORKING_SETENV
+#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) && HAVE_FORK == 1
+#if HAVE_DECL_SETENV
 /* Environment Integer Timeout Tests */
     LINENO_eternal,
     "-1",
@@ -743,7 +921,7 @@ void init_master_tests_lineno(int num_master_tests) {
     LINENO_sleep2,
     LINENO_sleep5,
     LINENO_sleep9,
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 /* Default Timeout Tests */
     LINENO_eternal,
 #ifdef HAVE_LIBRT
@@ -777,7 +955,7 @@ void init_master_tests_lineno(int num_master_tests) {
     "-1",
     LINENO_sleep5,
     LINENO_sleep9,
-#if HAVE_WORKING_SETENV
+#if HAVE_DECL_SETENV
 /* Environment Integer Timeout Scaling Tests */
     LINENO_eternal,
 #ifdef HAVE_LIBRT
@@ -836,17 +1014,19 @@ void init_master_tests_lineno(int num_master_tests) {
     LINENO_sleep5,
     LINENO_sleep9,
     LINENO_sleep14,
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 #endif /* TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) */
 
 /* Limit Tests */
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
     "-1",
 #endif /* HAVE_FORK */
+#if MEMORY_LEAKING_TESTS_ENABLED
     "-1",
+#endif /* MEMORY_LEAKING_TESTS_ENABLED */
     "-1",
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
 /* Msg and fork Tests */
     "-1",
     "-1",
@@ -856,6 +1036,14 @@ void init_master_tests_lineno(int num_master_tests) {
     "-1",
 #endif /* HAVE_FORK */
 
+#if defined(HAVE_FORK) && HAVE_FORK==1
+/* Check Errors Tests */
+#if MEMORY_LEAKING_TESTS_ENABLED
+    LINENO_invalid_set_fork_status,
+#endif
+    LINENO_ck_ignore_exit_handlers,
+#endif /* HAVE_FORK */
+
 /* Core */
     "-1",
     "-1"
@@ -880,48 +1068,52 @@ Suite *make_sub_suite(void)
   Suite *s;
 
   TCase *tc_simple;
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   TCase *tc_signal;
 #endif
-#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK)
-#if HAVE_WORKING_SETENV
+#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) && HAVE_FORK == 1
+#if HAVE_DECL_SETENV
   TCase *tc_timeout_env_int;
   TCase *tc_timeout_env_double;
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
   TCase *tc_timeout_default;
   TCase *tc_timeout_usr_int;
   TCase *tc_timeout_usr_double;
-#if HAVE_WORKING_SETENV
+#if HAVE_DECL_SETENV
   TCase *tc_timeout_env_scale_int;
   TCase *tc_timeout_scale_int;
   TCase *tc_timeout_usr_scale_int;
   TCase *tc_timeout_env_scale_double;
   TCase *tc_timeout_scale_double;
   TCase *tc_timeout_usr_scale_double;
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 #endif /* TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) */
   TCase *tc_limit;
+#if defined(HAVE_FORK) && HAVE_FORK==1
   TCase *tc_messaging_and_fork;
+  TCase *tc_errors;
+  TCase *tc_exit_handlers;
+#endif
 
   s = suite_create("Check Servant");
 
   tc_simple = tcase_create("Simple Tests");
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   tc_signal = tcase_create("Signal Tests");
 #endif /* HAVE_FORK */
-#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK)
-#if HAVE_WORKING_SETENV
+#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) && HAVE_FORK == 1
+#if HAVE_DECL_SETENV
   setenv("CK_DEFAULT_TIMEOUT", "6", 1);
   tc_timeout_env_int = tcase_create("Environment Integer Timeout Tests");
   unsetenv("CK_DEFAULT_TIMEOUT");
   setenv("CK_DEFAULT_TIMEOUT", "0.5", 1);
   tc_timeout_env_double = tcase_create("Environment Double Timeout Tests");
   unsetenv("CK_DEFAULT_TIMEOUT");
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
   tc_timeout_default = tcase_create("Default Timeout Tests");
   tc_timeout_usr_int = tcase_create("User Integer Timeout Tests");
   tc_timeout_usr_double = tcase_create("User Double Timeout Tests");
-#if HAVE_WORKING_SETENV
+#if HAVE_DECL_SETENV
   setenv("CK_TIMEOUT_MULTIPLIER", "2", 1);
   tc_timeout_scale_int = tcase_create("Timeout Integer Scaling Tests");
   tc_timeout_usr_scale_int = tcase_create("User Integer Timeout Scaling Tests");
@@ -937,40 +1129,48 @@ Suite *make_sub_suite(void)
   tc_timeout_env_scale_double = tcase_create("Environment Double Timeout Scaling Tests");
   unsetenv("CK_DEFAULT_TIMEOUT");
   unsetenv("CK_TIMEOUT_MULTIPLIER");
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 #endif /* TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) */
   tc_limit = tcase_create("Limit Tests");
+#if defined(HAVE_FORK) && HAVE_FORK==1
   tc_messaging_and_fork = tcase_create("Msg and fork Tests");
+  tc_errors = tcase_create("Check Errors Tests");
+  tc_exit_handlers = tcase_create("Check Ignore Exit Handlers");
+#endif /* HAVE_FORK */
 
   suite_add_tcase (s, tc_simple);
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   suite_add_tcase (s, tc_signal);
 #endif /* HAVE_FORK */
-#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK)
-#if HAVE_WORKING_SETENV
+#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) && HAVE_FORK == 1
+#if HAVE_DECL_SETENV
   suite_add_tcase (s, tc_timeout_env_int);
   suite_add_tcase (s, tc_timeout_env_double);
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
   suite_add_tcase (s, tc_timeout_default);
   suite_add_tcase (s, tc_timeout_usr_int);
   suite_add_tcase (s, tc_timeout_usr_double);
 
   /* Add a second time to make sure tcase_set_timeout doesn't contaminate it. */
   suite_add_tcase (s, tc_timeout_default);
-#if HAVE_WORKING_SETENV
+#if HAVE_DECL_SETENV
   suite_add_tcase (s, tc_timeout_env_scale_int);
   suite_add_tcase (s, tc_timeout_env_scale_double);
   suite_add_tcase (s, tc_timeout_scale_int);
   suite_add_tcase (s, tc_timeout_scale_double);
   suite_add_tcase (s, tc_timeout_usr_scale_int);
   suite_add_tcase (s, tc_timeout_usr_scale_double);
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 #endif /* TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) */
   suite_add_tcase (s, tc_limit);
+#if defined(HAVE_FORK) && HAVE_FORK == 1
   suite_add_tcase (s, tc_messaging_and_fork);
+  suite_add_tcase (s, tc_errors);
+  suite_add_tcase (s, tc_exit_handlers);
+#endif
 
   tcase_add_test (tc_simple, test_lno);
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   tcase_add_test (tc_simple, test_mark_lno);
 #endif
   tcase_add_test (tc_simple, test_pass);
@@ -998,18 +1198,30 @@ Suite *make_sub_suite(void)
   tcase_add_test (tc_simple, test_ck_assert);
   tcase_add_test (tc_simple, test_ck_assert_null);
   tcase_add_test (tc_simple, test_ck_assert_int_eq);
+  tcase_add_test (tc_simple, test_ck_assert_int_eq_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_int_ne);
+  tcase_add_test (tc_simple, test_ck_assert_int_ne_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_int_lt);
+  tcase_add_test (tc_simple, test_ck_assert_int_lt_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_int_le);
+  tcase_add_test (tc_simple, test_ck_assert_int_le_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_int_gt);
+  tcase_add_test (tc_simple, test_ck_assert_int_gt_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_int_ge);
+  tcase_add_test (tc_simple, test_ck_assert_int_ge_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_int_expr);
   tcase_add_test (tc_simple, test_ck_assert_uint_eq);
+  tcase_add_test (tc_simple, test_ck_assert_uint_eq_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_uint_ne);
+  tcase_add_test (tc_simple, test_ck_assert_uint_ne_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_uint_lt);
+  tcase_add_test (tc_simple, test_ck_assert_uint_lt_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_uint_le);
+  tcase_add_test (tc_simple, test_ck_assert_uint_le_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_uint_gt);
+  tcase_add_test (tc_simple, test_ck_assert_uint_gt_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_uint_ge);
+  tcase_add_test (tc_simple, test_ck_assert_uint_ge_with_mod);
   tcase_add_test (tc_simple, test_ck_assert_uint_expr);
   tcase_add_test (tc_simple, test_ck_assert_str_eq);
   tcase_add_test (tc_simple, test_ck_assert_str_ne);
@@ -1021,7 +1233,7 @@ Suite *make_sub_suite(void)
   tcase_add_test (tc_simple, test_ck_assert_ptr_eq);
   tcase_add_test (tc_simple, test_ck_assert_ptr_ne);
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   tcase_add_test (tc_signal, test_segv);
   tcase_add_test_raise_signal (tc_signal, test_segv, 11); /* pass  */
   tcase_add_test_raise_signal (tc_signal, test_segv, 8);  /* error */
@@ -1031,8 +1243,8 @@ Suite *make_sub_suite(void)
   tcase_add_test (tc_signal, test_mark_point);
 #endif /* HAVE_FORK */
 
-#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK)
-#if HAVE_WORKING_SETENV
+#if TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) && HAVE_FORK == 1
+#if HAVE_DECL_SETENV
   tcase_add_test (tc_timeout_env_int, test_eternal);
   tcase_add_test (tc_timeout_env_int, test_sleep2);
   tcase_add_test (tc_timeout_env_int, test_sleep5);
@@ -1045,7 +1257,7 @@ Suite *make_sub_suite(void)
   tcase_add_test (tc_timeout_env_double, test_sleep2);
   tcase_add_test (tc_timeout_env_double, test_sleep5);
   tcase_add_test (tc_timeout_env_double, test_sleep9);
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 
   tcase_add_test (tc_timeout_default, test_eternal);
 #ifdef HAVE_LIBRT
@@ -1072,7 +1284,7 @@ Suite *make_sub_suite(void)
   tcase_add_test (tc_timeout_usr_double, test_sleep5);
   tcase_add_test (tc_timeout_usr_double, test_sleep9);
   
-#if HAVE_WORKING_SETENV
+#if HAVE_DECL_SETENV
   tcase_add_test (tc_timeout_env_scale_int, test_eternal);
 #ifdef HAVE_LIBRT
   tcase_add_test (tc_timeout_env_scale_int, test_sleep0_025);
@@ -1136,22 +1348,30 @@ Suite *make_sub_suite(void)
   tcase_add_test (tc_timeout_usr_scale_double, test_sleep5);
   tcase_add_test (tc_timeout_usr_scale_double, test_sleep9);
   tcase_add_test (tc_timeout_usr_scale_double, test_sleep14);
-#endif /* HAVE_WORKING_SETENV */
+#endif /* HAVE_DECL_SETENV */
 #endif /* TIMEOUT_TESTS_ENABLED && defined(HAVE_FORK) */
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   tcase_add_test (tc_limit, test_early_exit);
 #endif /* HAVE_FORK */
+#if MEMORY_LEAKING_TESTS_ENABLED
   tcase_add_test (tc_limit, test_null);
+#endif /* MEMORY_LEAKING_TESTS_ENABLED */
   tcase_add_test (tc_limit, test_null_2);
 
-#ifdef HAVE_FORK
+#if defined(HAVE_FORK) && HAVE_FORK==1
   tcase_add_test (tc_messaging_and_fork, test_fork1p_pass);
   tcase_add_test (tc_messaging_and_fork, test_fork1p_fail);
   tcase_add_test (tc_messaging_and_fork, test_fork1c_pass);
   tcase_add_test (tc_messaging_and_fork, test_fork1c_fail);
   tcase_add_test (tc_messaging_and_fork, test_fork2_pass);
   tcase_add_test (tc_messaging_and_fork, test_fork2_fail);
+
+#if MEMORY_LEAKING_TESTS_ENABLED
+  tcase_add_test_raise_signal (tc_errors, test_invalid_set_fork_status, 2);
+#endif
+
+  tcase_add_test (tc_exit_handlers, test_ignore_exit_handlers);
 #endif /* HAVE_FORK */
 
   return s;
